@@ -1,6 +1,6 @@
 package Business::BalancedPayments;
 
-our $VERSION = '1.0500'; # VERSION
+our $VERSION = '1.0600'; # VERSION
 
 use Business::BalancedPayments::V10;
 use Business::BalancedPayments::V11;
@@ -33,7 +33,7 @@ Business::BalancedPayments - Balanced Payments API bindings
 
 =head1 VERSION
 
-version 1.0500
+version 1.0600
 
 =head1 SYNOPSIS
 
@@ -341,10 +341,12 @@ Example response:
 =head2 create_debit
 
     create_debit($debit, card => $card)
+    create_debit($debit, bank => $bank)
 
-Debits a card.
+Debits a card or a bank.
 The C<$debit> hashref must contain an amount.
 The card param is a hashref such as one returned from L</get_card>.
+The bank param is a hashref such as one returned from L</get_bank_account>.
 Returns the created debit.
 
 Example:
