@@ -1,8 +1,8 @@
 package Business::BalancedPayments::V10;
 use Moo;
-with 'Business::BalancedPayments::Base';
+extends 'Business::BalancedPayments::Base';
 
-our $VERSION = '1.0500'; # VERSION
+our $VERSION = '1.0600'; # VERSION
 
 use Carp qw(croak);
 
@@ -242,7 +242,7 @@ Business::BalancedPayments::V10
 
 =head1 VERSION
 
-version 1.0500
+version 1.0600
 
 =head1 METHODS
 
